可拖拽面板 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# Nestable lists Drag & drop hierarchical list

1. Item 1
2. Item 2
   1. Item 3
   2. Item 4 with some description
   3. Item 5
      1. Item 6
      2. Item 7
      3. Item 8
   4. Item 9
   5. Item 10
3. Item 11
4. Item 12

1. Click on an icon to start dragging
2. Recent Posts
3. Statistics
   1. Active Users
   2. Published Articles
   3. Visitors
4. Menu

Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container